
#include <iostream>
#include <iomanip>
#include <complex>
#include <cmath>
using namespace std;

#define EPS (1E-12)
#define EQ(x,y) (fabs((x)-(y))<EPS)

typedef complex<double> xy;
const double PI = atan(1.0)*4.0;

xy points[100];
int n;

bool xy_less(const xy &a, const xy &b){
	return a.real() <b.real() ||(a.real()==b.real()&&a.imag()<b.imag());
}

double normalize_arg(double a){
	while(a>=PI) a-= PI;
	while(a<0) a+= PI;
	return a;
}
void update_ans(double &min_arg, double &min_score,
								double &max_arg, double &max_score,
								double &cur_arg, double &cur_score){
	if(min_score > cur_score){
		min_arg   = cur_arg;
		min_score = cur_score;
	}
	if(max_score < cur_score){
		max_arg   = cur_arg;
		max_score = cur_score;
	}
}
double ys[100];
double calc_score(double r){
	double ans;
	double base;
	xy rot = xy(cos(-r), sin(-r));
	for(int i=0;i<n;i++)
		ys[i] = (points[i]*rot).imag();
	sort(ys, ys+n);
	ans = 2.0;
	for(int i=0;i<n-1;i++)
		ans += min(2.0, ys[i+1]-ys[i]);
	return ans;
}
pair<int,int> connections[100];
int connections_sz;
pair<double,int> y_idxs[100];
void calc_connection(double r){
	connections_sz = 0;
	xy rot = xy(cos(-r), sin(-r));
	for(int i=0;i<n;i++)
		y_idxs[i] = make_pair((points[i]*rot).imag(), i);
	sort(y_idxs, y_idxs+n);
	for(int i=0;i<n; i++){
		int end = i;
		while(end != n-1 && y_idxs[end+1].first-y_idxs[end].first<2.0) end++;
		if(end != i)
			connections[connections_sz++]=make_pair(y_idxs[i].second,y_idxs[end].second);
		i = end;
	}
}

double events[20005];
int events_sz;
int main(void){
	while(true){
		cin >> n;
		if(!n) break;
		for(int i=0;i<n;i++){
			double x,y;
			cin >> x >> y;
			points[i]=xy(x,y);
		}
		events[0]=0.0;
		events[1]=PI/2.0;
		events[2]=PI;
		events_sz=3;
		for(int i=0;i<n;i++){
			for(int j=i+1;j<n;j++){
				double dist = abs(points[i]-points[j]);
				double darg = asin(2.0/dist);
				double narg = arg(points[i]-points[j]);
				if(EQ(dist,2.0)) continue;
				events[events_sz++] = normalize_arg(narg);
				events[events_sz++] = normalize_arg(narg+darg);
				events[events_sz++] = normalize_arg(narg-darg);
			}
		}
		sort(events, events + events_sz);
		double min_arg, max_arg, min_score = 1E10, max_score = -1.0;
		// exactly
		for(int i=0;i<events_sz; i++){
			double e = events[i];
			double score = calc_score(e);
			update_ans(min_arg, min_score, max_arg, max_score, e, score);
		}
		// middle event
		for(int i=0;i<events_sz-1; i++){
			double e1 = events[i];
			double e2 = events[i+1];
			double em = (e1+e2)/2.0;
			if(EQ(e1,e2)) continue;
			calc_connection(em);
			double a = 0.0, b = 0.0; // a sin(r)+b cos(r) 
			if(connections_sz==0) continue;
			for(int i=0;i<connections_sz;i++){
				int t1 = connections[i].first;
				int t2 = connections[i].second;
				double L = abs(points[t1]-points[t2]);
				double narg = arg(points[t1]-points[t2]);
				// target len = L sin(narg - r) = L sin(r+PI-narg)
				a += L * cos(PI-narg);
				b += L * sin(PI-narg);
			}
			if(a==0.0 && b==0.0) continue; // cause NaN
			double alpha = asin(b/sqrt(a*a+b*b));
			if(a<0.0)
				alpha  = PI - alpha;
			double trg[2];
			trg[0] = normalize_arg(PI/2.0 - alpha);
			trg[1] = normalize_arg(-PI/2.0 - alpha);
			for(int j=0;j<2;j++)
				if(e1 < trg[j] && trg[j] < e2){
					double score = calc_score(trg[j]);
					update_ans(min_arg, min_score, max_arg, max_score, trg[j], score);
				}
		}
		min_arg = PI - min_arg;
		max_arg = PI - max_arg;
		cout << fixed << setprecision(10) << min_arg << endl;
		cout << fixed << setprecision(10) << max_arg << endl;
	}
	return 0;
}
